@@ -25,6 +25,9 @@
 #include "box_data_list.h"
 #include "box_data_details.h"
 
+namespace Glom
+{
+
 class Notebook_Data : public Notebook_Glom
 {
 public: 
@@ -32,10 +35,10 @@ public:
   virtual ~Notebook_Data();
 
   //Create the layout for the database structure, and fill it with data.
-  virtual bool init_db_details(const Glib::ustring& table_name, const Glib::ustring& where_clause = Glib::ustring());
+  virtual bool init_db_details(const FoundSet& found_set, const Gnome::Gda::Value& primary_key_value_for_details = Gnome::Gda::Value());
 
   ///Get the existing where clause, previously supplied to init_db_details().
-  Glib::ustring get_where_clause() const;
+  FoundSet get_found_set() const;
 
   ///Show the details for a particular record, without affecting the list view:
   virtual void show_details(const Gnome::Gda::Value& primary_key_value);
@@ -66,7 +69,7 @@ protected:
 
   //Signal handlers:
   virtual void on_list_user_requested_details(const Gnome::Gda::Value& primary_key_value);
-  void on_Details_user_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value);
+  void on_details_user_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value);
 
   virtual void on_switch_page_handler(GtkNotebookPage* pPage, guint uiPageNumber);
 
@@ -79,4 +82,6 @@ protected:
   type_signal_record_details_requested m_signal_record_details_requested;
 };
 
+} //namespace Glom
+
 #endif
