@@ -22,10 +22,13 @@
 #define GLOM_UTILITY_WIDGETS_COMBOENTRY_GLOM_H
 
 #include <gtkmm.h>
-#include "../data_structure/field.h"
+#include <glom/libglom/data_structure/field.h>
 #include "comboglomchoicesbase.h"
 #include <libglademm.h>
 
+namespace Glom
+{
+
 class App_Glom;
 
 class ComboEntryGlom
@@ -55,9 +58,12 @@ public:
 
   virtual void set_layout_item(const sharedptr<LayoutItem>& layout_item, const Glib::ustring& table_name);
 
+  virtual void set_read_only(bool read_only = true);
+
 protected:
   void init();
 
+
   //Overrides of default signal handlers:
   virtual void on_entry_changed(); //From Gtk::Entry.
   virtual void on_entry_activate(); //From Gtk::Entry.
@@ -76,5 +82,7 @@ protected:
   //Gnome::Gda::Value m_value; //The last-stored value. We have this because the displayed value might be unparseable.
 };
 
+} //namespace Glom
+
 #endif //GLOM_UTILITY_WIDGETS_COMBOENTRY_GLOM_H
 
